.. change::
    :tags: bug, orm
    :tickets: 8881
    :versions: 2.0.0b4

    Fixed issues in :func:`_orm.with_expression` where expressions that were
    composed of columns that were referenced from the enclosing SELECT would
    not render correct SQL in some contexts, in the case where the expression
    had a label name that matched the attribute which used
    :func:`_orm.query_expression`, even when :func:`_orm.query_expression` had
    no default expression. For the moment, if the :func:`_orm.query_expression`
    does have a default expression, that label name is still used for that
    default, and an additional label with the same name will continue to be
    ignored. Overall, this case is pretty thorny so further adjustments might
    be warranted.
